@@ -8,13 +8,17 @@ use Mo qw(build default is);
 use Mo::utils qw(check_array_object);
 use Wikibase::Datatype::Utils qw(check_entity);
 
-our $VERSION = 0.17;
+our $VERSION = 0.18;
 
 has forms => (
 	default => [],
 	is => 'ro',
 );
 
+has id => (
+	is => 'ro',
+);
+
 has language => (
 	is => 'ro',
 );
@@ -101,6 +105,7 @@ Wikibase::Datatype::Lexeme - Wikibase lexeme datatype.
 
  my $obj = Wikibase::Datatype::Lexeme->new(%params);
  my $forms_ar = $obj->forms;
+ my $id = $obj->id;
  my $language = $obj->language;
  my $lastrevid = $obj->lastrevid;
  my $lemmas_ar = $obj->lemmas;
@@ -133,6 +138,11 @@ Forms.
 Reference to array with Wikibase::Datatype::Form instances.
 Parameter is optional.
 
+=item * C<id>
+
+Id.
+Parameter is optional.
+
 =item * C<language>
 
 Language. Link to QID.
@@ -191,6 +201,14 @@ Get forms.
 
 Returns reference to array with Wikibase::Datatype::Form instances.
 
+=head2 C<id>
+
+ my $id = $obj->id;
+
+Get id.
+
+Returns string.
+
 =head2 C<language>
 
  my $language = $obj->language;
@@ -391,6 +409,7 @@ Returns string.
 
  # Main item.
  my $obj = Wikibase::Datatype::Lexeme->new(
+         'id' => 'L469',
          'lemmas' => [
                  Wikibase::Datatype::Value::Monolingual->new(
                          'language' => 'cs',
@@ -406,6 +425,7 @@ Returns string.
 
  # Print out.
  print "Title: ".$obj->title."\n";
+ print 'Id: '.$obj->id."\n";
  print "Statements:\n";
  foreach my $statement (@{$obj->statements}) {
          print "\tStatement:\n";
@@ -427,6 +447,7 @@ Returns string.
 
  # Output:
  # Title: Lexeme:L469
+ # Id: L469
  # Statements:
  #         Statement:
  #                 P31 -> Q5
@@ -475,12 +496,12 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-© Michal Josef Špaček 2020-2022
+© 2020-2022 Michal Josef Špaček
 
 BSD 2-Clause License
 
 =head1 VERSION
 
-0.17
+0.18
 
 =cut
