@@ -6,7 +6,7 @@ use warnings;
 use Mo qw(build default is);
 use Mo::utils qw(check_array_object check_required);
 
-our $VERSION = 0.17;
+our $VERSION = 0.18;
 
 has badges => (
 	is => 'ro',
@@ -187,12 +187,12 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-© Michal Josef Špaček 2020-2022
+© 2020-2022 Michal Josef Špaček
 
 BSD 2-Clause License
 
 =head1 VERSION
 
-0.17
+0.18
 
 =cut
