@@ -6,7 +6,7 @@ use warnings;
 use Mo qw(is);
 use Wikibase::Datatype::Utils qw(check_language);
 
-our $VERSION = 0.17;
+our $VERSION = 0.18;
 
 extends 'Wikibase::Datatype::Value';
 
@@ -172,12 +172,12 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-© Michal Josef Špaček 2020-2022
+© 2020-2022 Michal Josef Špaček
 
 BSD 2-Clause License
 
 =head1 VERSION
 
-0.17
+0.18
 
 =cut
